@@ -223,7 +223,7 @@ class MySQL:
 
 
     @staticmethod
-    def get_production_data_from_prod(self, query):
+    def get_production_data_from_prod(query):
         retry_count = 0
         while retry_count<5:
             cnx = mysql.connector.connect(user=aws.cred['DE_USER'],
@@ -241,7 +241,7 @@ class MySQL:
                 cnx.close()
 
     @staticmethod
-    def get_rows_array_from_query_prod(self, query):
+    def get_rows_array_from_query_prod(query):
         try:
             conn = mysql.connector.connect(user=aws.cred['DE_USER'],
                                             password=aws.cred['DE_USER_PASSWORD'],
@@ -258,7 +258,7 @@ class MySQL:
             conn.close()
 
     @staticmethod
-    def get_analytics_data(self, query, write_to_local=False, fileName="file.csv"):
+    def get_analytics_data(query, write_to_local=False, fileName="file.csv"):
         cnx = mysql.connector.connect(user=aws.cred['DATA_USER'],
                                       password=aws.cred['DATA_PWD'],
                                       host=aws.cred['ANAL_HOST'],
@@ -270,7 +270,7 @@ class MySQL:
             cnx.close()
             
     @staticmethod
-    def get_rows_array_from_query_anal(self, query):
+    def get_rows_array_from_query_anal(query):
         try:
             conn = mysql.connector.connect(user=aws.cred['DATA_USER'],
                                             password=aws.cred['DATA_PWD'],
@@ -287,7 +287,7 @@ class MySQL:
             conn.close()
 
     @staticmethod
-    def get_production_ads_new_data(self, query):
+    def get_production_ads_new_data(query):
         conn = mysql.connector.connect(user=aws.cred['ADS_USER'],
                                        password=aws.cred['ADS_PWD'],
                                        host=aws.cred['ADS_HOST'],
@@ -299,7 +299,7 @@ class MySQL:
             conn.close()
 
     @staticmethod
-    def get_rows_array_from_query_prod_ads(self, query):
+    def get_rows_array_from_query_prod_ads(query):
         try:
             conn = mysql.connector.connect(user=aws.cred['ADS_USER'],
                                            password=aws.cred['ADS_PWD'],
@@ -317,7 +317,7 @@ class MySQL:
 
 
     @staticmethod
-    def get_rows_array_from_query_magento(self, query):
+    def get_rows_array_from_query_magento(query):
         try:
             conn = mysql.connector.connect(user=aws.cred['MAGENTO_USER'],
                                             password=aws.cred['MAGENTO_PASSWD'],
@@ -334,7 +334,7 @@ class MySQL:
             conn.close()
 
     @staticmethod
-    def get_production_magento(self, query):
+    def get_production_magento(query):
 
 
         conn = mysql.connector.connect(user=aws.cred['MAGENTO_USER'],
@@ -348,7 +348,7 @@ class MySQL:
             conn.close()
 
     @staticmethod
-    def get_rows_array_from_query_gratification(self, query):
+    def get_rows_array_from_query_gratification(query):
         try:
                 conn = mysql.connector.connect(user=aws.cred['DATA_USER'],
                                                password=aws.cred['DATA_PWD'],
@@ -366,7 +366,7 @@ class MySQL:
                 cursor.close()
                 conn.close()
     @staticmethod
-    def get_gratification_data_from_query(self, query):
+    def get_gratification_data_from_query(query):
         conn = mysql.connector.connect(user=aws.cred['DATA_USER'],
                                        password=aws.cred['DATA_PWD'],
                                        host=aws.cred['GRATIFICATION_HOST'],
@@ -378,7 +378,7 @@ class MySQL:
             conn.close()
 
     @staticmethod
-    def get_rows_array_from_query_cms(self, query):
+    def get_rows_array_from_query_cms(query):
         try:
                 conn = mysql.connector.connect(user=aws.cred['CMS_USER'],
                                                password=aws.cred['CMS_PWD'],
@@ -397,7 +397,7 @@ class MySQL:
                 conn.close()
 
     @staticmethod
-    def get_cms_data_from_query(self, query):
+    def get_cms_data_from_query(query):
         conn = mysql.connector.connect(user=aws.cred['CMS_USER'],
                                        password=aws.cred['CMS_PWD'],
                                        host=aws.cred['CMS_HOST'],
